==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/LastQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastQuarterExpressionDescription } from "./LastQuarterExpressionDescription";
/**
 * @hidden
 */
export let LastQuarterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastQuarterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastQuarterExpressionDescriptionMetadata.a == null) {
                LastQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastQuarterExpressionDescriptionMetadata.c(LastQuarterExpressionDescriptionMetadata.a);
            }
            if (a.j(LastQuarterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(LastQuarterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastQuarterExpressionDescriptionMetadata.b(a);
            a.aa("LastQuarterExpression", () => new LastQuarterExpressionDescription());
            a.z("LastQuarterExpression", LastQuarterExpressionDescriptionMetadata.a);
        }
    }
    LastQuarterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastQuarterExpressionDescriptionMetadata, 'LastQuarterExpressionDescriptionMetadata');
    LastQuarterExpressionDescriptionMetadata.a = null;
    return LastQuarterExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LastQuarterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastQuarterExpressionDescription } from "./LastQuarterExpressionDescription";
/**
 * @hidden
 */
export let LastQuarterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastQuarterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastQuarterExpressionDescriptionMetadata.a == null) {
                LastQuarterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastQuarterExpressionDescriptionMetadata.c(LastQuarterExpressionDescriptionMetadata.a);
            }
            if (a.k(LastQuarterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(LastQuarterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastQuarterExpressionDescriptionMetadata.b(a);
            a.ac("LastQuarterExpression", () => new LastQuarterExpressionDescription());
            a.ab("LastQuarterExpression", LastQuarterExpressionDescriptionMetadata.a);
        }
    }
    LastQuarterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastQuarterExpressionDescriptionMetadata, 'LastQuarterExpressionDescriptionMetadata');
    LastQuarterExpressionDescriptionMetadata.a = null;
    return LastQuarterExpressionDescriptionMetadata;
})();
